@@ -12,22 +12,22 @@ Map::Tube::Node - Defines the node for Map::Tube
 
 =head1 VERSION
 
-Version 1.4
+Version 1.5
 
 =cut
 
-our $VERSION = '1.4';
+our $VERSION = '1.5';
 
 Readonly my $BAKERLOO => {
-    'Harrow & Wealdstone' => 'B1',
-    'Kenton'              => 'B2',
-    'South Kenton'        => 'B3',
-    'North Wembley'       => 'B4',
-    'Wembley Central'     => 'B5',
-    'Stonebridge Park'    => 'B6',
-    'Harlesden'           => 'B7',
-    'Willesdon Junction'  => 'B8',
-    'Kensal Green'        => 'B9',
+    'Harrow & Wealdstone' => 'B01',
+    'Kenton'              => 'B02',
+    'South Kenton'        => 'B03',
+    'North Wembley'       => 'B04',
+    'Wembley Central'     => 'B05',
+    'Stonebridge Park'    => 'B06',
+    'Harlesden'           => 'B07',
+    'Willesdon Junction'  => 'B08',
+    'Kensal Green'        => 'B09',
     q{Queen's Park}       => 'B10',
     'Kilburn Park'        => 'B11',
     'Maida Vale'          => 'B12',
@@ -38,13 +38,13 @@ Readonly my $BAKERLOO => {
 };
 
 Readonly my $CENTRAL => {
-    'West Ruislip'     => 'C1',
-    'Ruislip Gardens'  => 'C2',
-    'South Ruislip'    => 'C3',
-    'Northolt'         => 'C4',
-    'Greenford'        => 'C5',
-    'Perivale'         => 'C6',
-    'Hanger Lane'      => 'C7',
+    'West Ruislip'     => 'C01',
+    'Ruislip Gardens'  => 'C02',
+    'South Ruislip'    => 'C03',
+    'Northolt'         => 'C04',
+    'Greenford'        => 'C05',
+    'Perivale'         => 'C06',
+    'Hanger Lane'      => 'C07',
     'West Acton'       => 'C10',
     'East Acton'       => 'C11',
     q{Shepherd's Bush} => 'C13',
@@ -54,59 +54,58 @@ Readonly my $CENTRAL => {
     'Marble Arch'      => 'C18',
     'Chancery Lane'    => 'C23',
     q{St. Paul's}      => 'C24',
-    'Bethnal Green'    => 'C29',
-    'Stratford'        => 'C31',
-    'Leyton'           => 'C32',
-    'Wanstead'         => 'C34',
-    'Redbridge'        => 'C35',
-    'Gants Hill'       => 'C36',
-    'Newbury Park'     => 'C37',
-    'Barkingside'      => 'C38',
-    'Fairlop'          => 'C39',
-    'Hainault'         => 'C40',
-    'Grange Hill'      => 'C41',
-    'Chigwell'         => 'C42',
-    'Roding Valley'    => 'C43',
-    'Snaresbrook'      => 'C44',
-    'South Woodford'   => 'C45',
-    'Woodford'         => 'C46',
-    'Loughton'         => 'C48',
-    'Debden'           => 'C49',
-    'Theydon Bois'     => 'C50',
-    'Epping'           => 'C51'
+    'Bethnal Green'    => 'C27',
+    'Leyton'           => 'C30',
+    'Wanstead'         => 'C32',
+    'Redbridge'        => 'C33',
+    'Gants Hill'       => 'C34',
+    'Newbury Park'     => 'C35',
+    'Barkingside'      => 'C36',
+    'Fairlop'          => 'C37',
+    'Hainault'         => 'C38',
+    'Grange Hill'      => 'C39',
+    'Chigwell'         => 'C40',
+    'Roding Valley'    => 'C41',
+    'Snaresbrook'      => 'C42',
+    'South Woodford'   => 'C43',
+    'Woodford'         => 'C44',
+    'Loughton'         => 'C46',
+    'Debden'           => 'C47',
+    'Theydon Bois'     => 'C48',
+    'Epping'           => 'C49'
 };
 
 Readonly my $DISTRICT => {
-    'Upney'             => 'D29',
-    'Becontree'         => 'D30',
-    'Dagenham Heathway' => 'D31',
-    'Dagenham East'     => 'D32',
-    'Elm Park'          => 'D33',
-    'Hornchurch'        => 'D34',
-    'Upminster Bridge'  => 'D35',
-    'Upminster'         => 'D36',
-    'West Kensington'   => 'D38',
-    'Ravenscourt Park'  => 'D41',
-    'Stamford Brook'    => 'D42',
-    'Chiswick Park'     => 'D44',
-    'Fulham Broadway'   => 'D52',
-    'Parsons Green'     => 'D53',
-    'Putney Bridge'     => 'D54',
-    'East Putney'       => 'D55',
-    'Southfields'       => 'D56',
-    'Wimbledon Park'    => 'D57',
-    'Wimbledon'         => 'D58',
+    'Chiswick Park'     => 'D04',
+    'Stamford Brook'    => 'D06',
+    'Ravenscourt Park'  => 'D07',
+    'West Kensington'   => 'D10',
+    'Fulham Broadway'   => 'D14',
+    'Parsons Green'     => 'D15',
+    'Putney Bridge'     => 'D16',
+    'East Putney'       => 'D17',
+    'Southfields'       => 'D18',
+    'Wimbledon Park'    => 'D19',
+    'Wimbledon'         => 'D20',
+    'Upney'             => 'D48',
+    'Becontree'         => 'D49',
+    'Dagenham Heathway' => 'D50',
+    'Dagenham East'     => 'D51',
+    'Elm Park'          => 'D52',
+    'Hornchurch'        => 'D53',
+    'Upminster Bridge'  => 'D54',
+    'Upminster'         => 'D55',
 };
 
 Readonly my $JUBILEE => {
-    'Stanmore'         => 'J1',
-    'Canons Park'      => 'J2',
-    'Queensbury'       => 'J3',
-    'Kingsbury'        => 'J4',
-    'Neasden'          => 'J6',
-    'Dollis Hill'      => 'J7',
-    'Willesden Green'  => 'J8',
-    'Kilburn'          => 'J9',
+    'Stanmore'         => 'J01',
+    'Canons Park'      => 'J02',
+    'Queensbury'       => 'J03',
+    'Kingsbury'        => 'J04',
+    'Neasden'          => 'J06',
+    'Dollis Hill'      => 'J07',
+    'Willesden Green'  => 'J08',
+    'Kilburn'          => 'J09',
     'West Hampstead'   => 'J10',
     'Swiss Cottage'    => 'J12',
     q{St. John's Wood} => 'J13',
@@ -116,40 +115,38 @@ Readonly my $JUBILEE => {
     'Canary Wharf'     => 'J23',
     'North Greenwich'  => 'J24',
     'Canning Town'     => 'J25',
-    'Stratford'        => 'J27'
 };
 
 Readonly my $METROPOLITAN => {
-    'Preston Road'    => 'M12',
-    'Norhtwick Park'  => 'M13',
-    'West Harrow'     => 'M15',
-    'North Harrow'    => 'M23',
-    'Pinner'          => 'M24',
-    'Northwood Hills' => 'M25',
-    'Northwood'       => 'M26',
-    'Croxley'         => 'M28',
-    'Watford'         => 'M29',
-    'Rickmansworth'   => 'M30',
-    'Chorleywood'     => 'M31',
-    'Chesham'         => 'M33',
-    'Amersham'        => 'M34'
+    'West Harrow'     => 'M07',
+    'North Harrow'    => 'M09',
+    'Pinner'          => 'M10',
+    'Northwood Hills' => 'M11',
+    'Northwood'       => 'M12',
+    'Croxley'         => 'M14',
+    'Watford'         => 'M15',
+    'Rickmansworth'   => 'M16',
+    'Chorleywood'     => 'M17',
+    'Chesham'         => 'M19',
+    'Amersham'        => 'M20',
+    'Norhtwick Park'  => 'M21',
+    'Preston Road'    => 'M22',
 };
 
 Readonly my $NORTHERN => {
-    'Edgware'                => 'N1',
-    'Burnt Oak'              => 'N2',
-    'Collindale'             => 'N3',
-    'Hendon Central'         => 'N4',
-    'Brent Cross'            => 'N5',
-    'Hampstead'              => 'N6',
-    'Belsize Park'           => 'N7',
-    'Chalk Farm'             => 'N8',
+    'Edgware'                => 'N01',
+    'Burnt Oak'              => 'N02',
+    'Collindale'             => 'N03',
+    'Hendon Central'         => 'N04',
+    'Brent Cross'            => 'N05',
+    'Hampstead'              => 'N06',
+    'Belsize Park'           => 'N07',
+    'Chalk Farm'             => 'N08',
     'Kentish Town'           => 'N10',
     'Tufnell Park'           => 'N11',
     'Archway'                => 'N12',
     'Highgate'               => 'N13',
     'East Finchley'          => 'N14',
-    'Finchley Central'       => 'FCC',
     'Mill Hill East'         => 'N16',
     'West Finchley'          => 'N17',
     'Woodside Park'          => 'N18',
@@ -173,44 +170,44 @@ Readonly my $NORTHERN => {
 };
 
 Readonly my $PICCADILLY => {
-    'South Harrow'            => 'P8',
-    'Sudbury Hill'            => 'P9',
+    'South Harrow'            => 'P08',
+    'Sudbury Hill'            => 'P09',
     'Sudbury Town'            => 'P10',
+    'Alperton'                => 'P11',
     'Park Royal'              => 'P12',
     'North Ealing'            => 'P13',
-    'Knightsbridge'           => 'P22',
-    'Hyde Park Corner'        => 'P23',
-    'Covent Garden'           => 'P27',
-    'Russel Square'           => 'P29',
-    'Caledonian Road'         => 'P31',
-    'Holloway Road'           => 'P32',
-    'Arsenal'                 => 'P33',
-    'Manor House'             => 'P35',
-    'Turnpike Lane'           => 'P36',
-    'Wood Green'              => 'P37',
-    'Bounds Green'            => 'P38',
-    'Arnos Grove'             => 'P39',
-    'Southgate'               => 'P40',
-    'Oakwood'                 => 'P41',
-    'Cockfosters'             => 'P42',
-    'South Ealing'            => 'P43',
-    'Northfields'             => 'P44',
-    'Boston Manor'            => 'P45',
-    'Osterley'                => 'P46',
-    'Hounslow East'           => 'P47',
-    'Hounslow Central'        => 'P48',
-    'Hounslow West'           => 'P49',
-    'Hatton Cross'            => 'P50',
-    'Heathrow Terminal 4'     => 'P51',
-    'Heathrow Terminal 1,2,3' => 'P52',
-    'Heathrow Terminal 5'     => 'P53'
+    'Knightsbridge'           => 'P19',
+    'Hyde Park Corner'        => 'P20',
+    'Covent Garden'           => 'P24',
+    'Russel Square'           => 'P26',
+    'Caledonian Road'         => 'P29',
+    'Holloway Road'           => 'P30',
+    'Arsenal'                 => 'P31',
+    'Manor House'             => 'P33',
+    'Turnpike Lane'           => 'P34',
+    'Wood Green'              => 'P35',
+    'Bounds Green'            => 'P36',
+    'Arnos Grove'             => 'P37',
+    'Southgate'               => 'P38',
+    'Oakwood'                 => 'P39',
+    'Cockfosters'             => 'P40',
+    'South Ealing'            => 'P41',
+    'Northfields'             => 'P42',
+    'Boston Manor'            => 'P43',
+    'Osterley'                => 'P44',
+    'Hounslow East'           => 'P45',
+    'Hounslow Central'        => 'P46',
+    'Hounslow West'           => 'P47',
+    'Hatton Cross'            => 'P48',
+    'Heathrow Terminal 4'     => 'P49',
+    'Heathrow Terminal 1,2,3' => 'P50',
+    'Heathrow Terminal 5'     => 'P51'
 };
 
 Readonly my $VICTORIA => {
-    'Brixton'              => 'V1',
-    'Vauxhall'             => 'V3',
-    'Pimlico'              => 'V4',
-    'Euston'               => 'V9',
+    'Brixton'              => 'V01',
+    'Vauxhall'             => 'V03',
+    'Pimlico'              => 'V04',
     'Highbury & Islington' => 'V11',
     'Seven Sisters'        => 'V13',
     'Tottenham Hale'       => 'V14',
@@ -250,6 +247,7 @@ Readonly my $COMMON => {
     'Euston Square'             => 'ESQ',
     'Farringdon'                => 'FRG',
     'Finchley Road'             => 'FNR',
+    'Finchley Central'          => 'FCC',
     'Finsbury Park'             => 'FBP',
     'Gloucester Road'           => 'GLS',
     'Goldhawk Road'             => 'GHR',
@@ -294,6 +292,7 @@ Readonly my $COMMON => {
     q{St. James's Park}         => 'SJP',
     'Stepney Green'             => 'SGN',
     'Stockwell'                 => 'STW',
+    'Stratford'                 => 'STF',
     'Temple'                    => 'TMP',
     'Tottenham Court Road'      => 'TCR',
     'Tower Hill'                => 'THL',
@@ -313,6 +312,50 @@ Readonly my $COMMON => {
     'Wood Lane'                 => 'WDL',
 };
 
+Readonly my $LINE => {
+    'Bakerloo'           => ['B01','B02','B03','B04','B05','B06','B07','B08','B09','B10',
+                             'B11','B12','B13','PDG','EDG','B16','BST','B18','OXC','PCS',
+                             'CRS','EBK','WLO','B24','EAC'],
+    'Central'            => ['C01','C02','C03','C04','C05','C06','C07','NAC','EBW','C10',
+                             'C11','WTC','C13','C14','NHG','C16','C17','C18','BOS','OXC',
+                             'TCR','HBR','C23','C24','BNK','LST','C27','MEN','STF','C30',
+                             'LES','C32','C33','C34','C35','C36','C37','C38','C39','C40',
+                             'C41','C42','C43','C44','BHH','C46','C47','C48','C49'],
+    'Circle'             => ['HSM','GHR','SBM','WDL','LTR','LBG','WBP','RYL','PDG','EDG',
+                             'BST','GPS','ESQ','KCS','FRG','BBC','MGT','LST','AGT','THL',
+                             'MMT','CNS','MSH','BLF','TMP','EBK','WMN','SJP','VCT','SLQ',
+                             'SKN','GLS','HSK','NHG','BYW'],
+    'District'           => ['EBW','ECM','ACT','D04','TGN','D06','D07','HSM','BCT','D10',
+                             'ECT','KSG','WBM','D14','D15','D16','D17','D18','D19','D20',
+                             'HSK','NHG','BYW','EDG','GLS','SKN','SLQ','VCT','SJP','WMN',
+                             'EBK','TMP','BLF','MSH','CNS','MMT','THL','AGE','WCH','SGN',
+                             'MEN','BRD','BBB','WHM','PST','EHM','BKG','D48','D49','D50',
+                             'D51','D52','D53','D54','D55','GBY','KGN','RCH'],
+    'Hammersmith & City' => ['HSM','GHR','SBM','WDL','LTR','LBG','WBP','RYL','PDG','EDG',
+                             'BST','GPS','ESQ','KCS','FRG','BBC','MGT','LST','AGE','WCH',
+                             'SGN','MEN','BRD','BBB','WHM','PST','UPK','EHM','BKG'],
+    'Jubilee'            => ['J01','J02','J03','J04','WMB','J06','J07','J08','J09','J10',
+                             'FNR','J12','J13','BST','BOS','GPK','WMN','WLO','J19','LON',
+                             'J21','J22','J23','J24','J25','STF'],
+    'Metropolitan'       => ['UXB','HGD','IKH','RSP','RSM','ETC','M07','HOH','M09','M10',
+                             'M11','M12','MPK','M14','M15','M16','M17','CAL','M19','M20',
+                             'M21','M22','WMB','FNR','BST','GPS','ESQ','KCS','FRG','BBC',
+                             'MGT','LST','AGT'],
+    'Northern'           => ['N01','N02','N03','N04','N05','N06','N07','N08','CAT','N10',
+                             'N11','N12','N13','N14','FCC','N16','N17','N18','N19','N20',
+                             'N21','EUS','WST','N24','TCR','LSQ','CRS','EBK','WLO','KNG',
+                             'N31','STW','N33','N34','N35','N36','N37','N38','N39','N40',
+                             'N41','N42','LON','BNK','MGT','N46','N47'],
+    'Piccadilly'         => ['UXB','HGD','IKH','RSP','RSM','ETC','RAL','P08','P09','P10',
+                             'P11','P12','P13','ECM','ACT','TGN','HSM','BCT','P19','P20',
+                             'GPK','PCS','LSQ','P24','HBN','P26','KCS','P28','P29','P30',
+                             'P31','FBP','P33','P34','P35','P36','P37','P38','P39','P40',
+                             'P41','P42','P43','P44','P45','P46','P47','P48','P49','P50',
+                             'P51'],
+    'Victoria'           => ['V01','STW','V03','V04','VCT','GPK','OXC','WST','EUS','KCS',
+                             'V11','FBP','V13','V14','V15','V16']
+};
+
 =head1 SYNOPSIS
 
       B --------  C 
@@ -332,7 +375,7 @@ Readonly my $COMMON => {
     \
      \
       I 
-   
+
   which can be defined as below:
 
   { 'A' => ['B','F','G'],
@@ -355,26 +398,28 @@ among the diffrerent nodes. I have taken extra care to depict the relationship.
 However I would be more than happy to receieve any suggestion to improve the logic.
 Please note "Transport for London" is the owner of the data used here.
 
+  use strict; use warnings;
   use Map::Tube::Node;
-  
+
+  use strict; use warnings;
   # Loads up the default node mapping definitions.
   my $node = Map::Tube::Node::init();
-  
+
 =cut
 
 sub init {
     my $node = {
         ## BAKERLOO
-        'B1'  => ['B2'],
-        'B2'  => ['B1','B3'],
-        'B3'  => ['B2','B4'],
-        'B4'  => ['B3','B5'],
-        'B5'  => ['B4','B6'],
-        'B6'  => ['B5','B7'],
-        'B7'  => ['B6','B8'],
-        'B8'  => ['B7','B9'],
-        'B9'  => ['B8','B10'],
-        'B10' => ['B9','B11'],
+        'B01' => ['B02'],
+        'B02' => ['B01','B03'],
+        'B03' => ['B02','B04'],
+        'B04' => ['B03','B05'],
+        'B05' => ['B04','B06'],
+        'B06' => ['B05','B07'],
+        'B07' => ['B06','B08'],
+        'B08' => ['B07','B09'],
+        'B09' => ['B08','B10'],
+        'B10' => ['B09','B11'],
         'B11' => ['B10','B12'],
         'B12' => ['B11','B13'],
         'B13' => ['B12','PDG'],
@@ -383,13 +428,13 @@ sub init {
         'B24' => ['WLO','EAC'],
 
         ## CENTRAL
-        'C1'  => ['C2'],
-        'C2'  => ['C1','C3'],
-        'C3'  => ['C2','C4'],
-        'C4'  => ['C3','C5'],
-        'C5'  => ['C4','C6'],
-        'C6'  => ['C5','C7'],
-        'C7'  => ['C6','NAC'],
+        'C01' => ['C02'],
+        'C02' => ['C01','C03'],
+        'C03' => ['C02','C04'],
+        'C04' => ['C03','C05'],
+        'C05' => ['C04','C06'],
+        'C06' => ['C05','C07'],
+        'C07' => ['C06','NAC'],
         'C10' => ['EBW','C11'],
         'C11' => ['C10','WTC'],
         'C13' => ['WTC','C14'],
@@ -399,51 +444,57 @@ sub init {
         'C18' => ['C17','BOS'],
         'C23' => ['HBN','C24'],
         'C24' => ['C23','BNK'],
-        'C29' => ['LST','MEN'],
-        'C31' => ['MEN','C32'],
-        'C32' => ['C31','LES'],
-        'C34' => ['LES','C35'],
+        'C27' => ['LST','MEN'],
+        'C30' => ['STF','LES'],
+        'C32' => ['LES','C33'],
+        'C33' => ['C32','C34'],
+        'C34' => ['C33','C35'],
         'C35' => ['C34','C36'],
         'C36' => ['C35','C37'],
         'C37' => ['C36','C38'],
         'C38' => ['C37','C39'],
         'C39' => ['C38','C40'],
         'C40' => ['C39','C41'],
-        'C41' => ['C40','C42'],
-        'C42' => ['C41','C43'],
-        'C43' => ['C42','BHH'],
-        'C44' => ['LES','C45'],
-        'C45' => ['C44','C46'],
-        'C46' => ['BHH','C45'],
-        'C48' => ['BHH','C49'],
-        'C49' => ['C48','C50'],
-        'C50' => ['C49','C51'],
-        'C51' => ['C50'],
-
-        ## DISTRICT / HAMMERSMITHANDCITY
-        'D36' => ['D35'],
-        'D35' => ['D34','D36'],
-        'D34' => ['D33','D35'],
-        'D33' => ['D32','D34'],
-        'D32' => ['D31','D33'],
-        'D31' => ['D30','D32'],
-        'D30' => ['D29','D31'],
-        'D29' => ['BKG','D30'],
-        'D38' => ['ECT','BCT'],
-        'D41' => ['HSM','D42'],
-        'D42' => ['TGN','D41'],
-        'D44' => ['TGN','ACT'],
+        'C41' => ['C40','BHH'],
+        'C42' => ['LES','C43'],
+        'C43' => ['C42','C44'],
+        'C44' => ['BHH','C43'],
+        'C46' => ['BHH','C47'],
+        'C47' => ['C46','C48'],
+        'C48' => ['C47','C49'],
+        'C49' => ['C48'],
+        
+        ## DISTRICT / HAMMERSMITHANDCITY / CIRCLE
+        'D04' => ['TGN','ACT'],
+        'D06' => ['TGN','D07'],
+        'D07' => ['HSM','D06'],
+        'D10' => ['ECT','BCT'],
+        'D14' => ['WBM','D15'],
+        'D15' => ['D14','D16'],
+        'D16' => ['D15','D17'],
+        'D17' => ['D16','D18'],
+        'D18' => ['D17','D19'],
+        'D19' => ['D18','D20'],
+        'D20' => ['D19'],
+        'D48' => ['BKG','D49'],
+        'D49' => ['D48','D50'],
+        'D50' => ['D49','D51'],
+        'D51' => ['D50','D52'],
+        'D52' => ['D51','D53'],
+        'D53' => ['D52','D54'],
+        'D54' => ['D53','D55'],
+        'D55' => ['D54'],
 
         ## JUBILEE
-        'J1'  => ['J2'],
-        'J2'  => ['J1','J3'],
-        'J3'  => ['J2','J4'],
-        'J4'  => ['J3','WMB'],
-        'J6'  => ['WMB','J7'],
-        'J7'  => ['J6','J8'],
-        'J8'  => ['J7','J9'],
-        'J9'  => ['J8','J10'],
-        'J10' => ['J9','FNR'],
+        'J01' => ['J02'],
+        'J02' => ['J01','J03'],
+        'J03' => ['J02','J04'],
+        'J04' => ['J03','WMB'],
+        'J06' => ['WMB','J07'],
+        'J07' => ['J06','J08'],
+        'J08' => ['J07','J09'],
+        'J09' => ['J08','J10'],
+        'J10' => ['J09','FNR'],
         'J12' => ['FNR','J13'],
         'J13' => ['J12','BST'],
         'J19' => ['WLO','LON'],
@@ -452,31 +503,30 @@ sub init {
         'J23' => ['J22','J24'],
         'J24' => ['J23','J25'],
         'J25' => ['J24','WHM'],
-        'J27' => ['WHM'],
 
         ## METROPOLITAN
-        'M12' => ['FNR','M13'],
-        'M15' => ['HOH','RAL'],
-        'M23' => ['HOH','M24'],
-        'M24' => ['M23','M25'],
-        'M25' => ['M24','M26'],
-        'M26' => ['M25','MPK'],
-        'M28' => ['MPK','M29'],
-        'M29' => ['M28'],
-        'M30' => ['MPK','M31'],
-        'M31' => ['M30','CAL'],
-        'M33' => ['CAL'],
-        'M34' => ['CAL'],
+        'M22' => ['FNR','M21'],
+        'M07' => ['HOH','RAL'],
+        'M09' => ['HOH','M10'],
+        'M10' => ['M09','M11'],
+        'M11' => ['M10','M12'],
+        'M12' => ['M11','MPK'],
+        'M14' => ['MPK','M15'],
+        'M15' => ['M14'],
+        'M16' => ['MPK','M17'],
+        'M17' => ['M16','CAL'],
+        'M19' => ['CAL'],
+        'M20' => ['CAL'],
 
         ## NORTHERN
-        'N1'  => ['N2'],
-        'N2'  => ['N3','N1'],
-        'N3'  => ['N4','N2'],
-        'N4'  => ['N5','N3'],
-        'N5'  => ['N6','N4'],
-        'N6'  => ['N7','N5'],
-        'N7'  => ['N8','N6'],
-        'N8'  => ['CAT','N7'],
+        'N01' => ['N02'],
+        'N02' => ['N03','N01'],
+        'N03' => ['N04','N02'],
+        'N04' => ['N05','N03'],
+        'N05' => ['N06','N04'],
+        'N06' => ['N07','N05'],
+        'N07' => ['N08','N06'],
+        'N08' => ['CAT','N07'],
         'N10' => ['CAT','N11'],
         'N11' => ['N10','N12'],
         'N12' => ['N11','N13'],
@@ -504,50 +554,48 @@ sub init {
         'N47' => ['N46','KCS'],
 
         ## PICCADILLY
-        'P53' => ['P52'],
-        'P52' => ['P53','P50'],
-        'P51' => ['P52'],
-        'P50' => ['P51'],
-        'P49' => ['P50','P48'],
-        'P48' => ['P49','P47'],
-        'P47' => ['P48','P46'],
-        'P46' => ['P47','P45'],
-        'P45' => ['P46','P44'],
-        'P44' => ['P45','P43'],
-        'P43' => ['ACT','P44'],
-        'P42' => ['P41'],
-        'P41' => ['P40','P42'],
-        'P40' => ['P39','P41'],
-        'P39' => ['P38','P40'],
-        'P38' => ['P37','P39'],
-        'P37' => ['P36','P38'],
-        'P36' => ['P35','P37'],
-        'P35' => ['FBP','P36'],
-        'P33' => ['FBP','P32'],
-        'P32' => ['P33','P31'],
-        'P31' => ['P32','KCS'],
-        'P29' => ['KCS','HBN'],
-        'P27' => ['HBN','LSQ'],
-        'P23' => ['GPK','P22'],
-        'P22' => ['P23','SKN'],
-        'P13' => ['ECM','P12'],
-        'P12' => ['P13','P11'],
+        'P08' => ['RAL','P09'],
+        'P09' => ['P10','P08'],
+        'P10' => ['P11','P09'],
         'P11' => ['P12','P10'],
-        'P10' => ['P11','P9'],
-        'P9'  => ['P10','P8'],
-        'P8'  => ['RAL','P9'],
-         
+        'P12' => ['P13','P11'],
+        'P13' => ['ECM','P12'],
+        'P19' => ['P20','SKN'],
+        'P20' => ['GPK','P19'],
+        'P24' => ['HBN','LSQ'],
+        'P26' => ['KCS','HBN'],
+        'P29' => ['P30','KCS'],
+        'P30' => ['P31','P29'],
+        'P31' => ['FBP','P30'],
+        'P33' => ['FBP','P34'],
+        'P34' => ['P33','P35'],
+        'P35' => ['P34','P36'],
+        'P36' => ['P35','P37'],
+        'P37' => ['P36','P38'],
+        'P38' => ['P37','P39'],
+        'P39' => ['P38','P40'],
+        'P40' => ['P39'],
+        'P41' => ['ACT','P42'],
+        'P42' => ['P41','P43'],
+        'P43' => ['P42','P44'],
+        'P44' => ['P45','P41'],
+        'P45' => ['P46','P44'],
+        'P46' => ['P47','P45'],
+        'P47' => ['P48','P46'],
+        'P48' => ['P49'],
+        'P49' => ['P50'],
+        'P50' => ['P51','P48'],
+        'P51' => ['P50'],
+
         ## VICTORIA
-        'V1'  => ['STW'],
-        'V3'  => ['STW','V4'],
-        'V4'  => ['V3','VCT'],
-        'V9'  => ['WST','KCS'],
+        'V01' => ['STW'],
+        'V03' => ['STW','V04'],
+        'V04' => ['V03','VCT'],
         'V11' => ['KCS','FBP'],
         'V13' => ['FBP','V14'],
         'V14' => ['V13','V15'],
         'V15' => ['V14','V16'],
-        'V16' => ['V15','V17'],
-        'V17' => ['V16'],
+        'V16' => ['V15'],
 
         ## Special case
         'UXB' => ['HGD'],
@@ -573,10 +621,10 @@ sub init {
         'SLQ' => ['VCT','SKN'],
         'HSK' => ['GLS','NHG'],
         'BYW' => ['NHG','EDG'],
-        'BCT' => ['HSM','D38'],
+        'BCT' => ['HSM','D10'],
         'GBY' => ['TGN','KGN'],
         'KGN' => ['GBY','RCH'],
-        'BKG' => ['EHM','D29'],
+        'BKG' => ['EHM','D48'],
         'EHM' => ['UPK','BKG'],
         'UPK' => ['PST','EHM'],
         'PST' => ['WHM','UPK'],
@@ -589,56 +637,57 @@ sub init {
         'RSP' => ['RSM','IKH'],
         'IKH' => ['RSP','HGD'],
         'HGD' => ['IKH','UXB'],
-        'BHH' => ['C43','C46'],
+        'BHH' => ['C41','C44'],
         'EBW' => ['ECM','C10'],
         'AGE' => ['LST','THL'],
-        'STW' => ['V1','V3','N31'],
-        'NAC' => ['C7','C10','C11'],
-        'RAL' => ['M15','ETC','P8'],
+        'STF' => ['MEN','C30','WHM'],
+        'STW' => ['V01','V03','N31'],
+        'NAC' => ['C07','C10','C11'],
+        'RAL' => ['M07','ETC','P08'],
         'THL' => ['AGT','AGE','MMT'],
         'GLS' => ['SKN','HSK','ECT'],
-        'MPK' => ['M26','M28','M30'],
-        'CAL' => ['M31','M33','M34'],
+        'MPK' => ['M12','M14','M16'],
+        'CAL' => ['M17','M19','M20'],
         'CRS' => ['PCS','EBK','LSQ'],
         'EAC' => ['B24','KNG','N42'],
         'FCC' => ['N14','N16','N17'],
         'EUS' => ['WST','N21','KCS'],
         'LSQ' => ['TCR','CRS','PCS'],
         'KNG' => ['WLO','EAC','N31'],
-        'SKN' => ['SLQ','GLS','P22'],
+        'SKN' => ['SLQ','GLS','P19'],
         'ECM' => ['ACT','P13','EBW'],
         'PDG' => ['B13','EDG','RYL'],
         'EDG' => ['PDG','B16','BST'],
-        'LES' => ['C32','C34','C44'],
-        'NHG' => ['C14','C16','R2','R4'],
-        'VCT' => ['V4','GPK','R7','SJP'],
-        'CAT' => ['N8','N10','N21','EUS'],
-        'WST' => ['OXC','V9','EUS','N24'],
+        'LES' => ['C30','C32','C42'],
+        'WST' => ['OXC','EUS','N24'],
+        'NHG' => ['C14','C16','BYW','HSK'],
+        'VCT' => ['V04','GPK','SLQ','SJP'],
+        'CAT' => ['N08','N10','N21','EUS'],
         'BOS' => ['GPK','BST','OXC','C18'],
-        'MEN' => ['C29','C31','SGN','BRD'],
-        'WHM' => ['J25','J27','BBB','PST'],
-        'HSM' => ['GHR','BCT','D41','TGN'],
-        'ACT' => ['D44','ECM','P43','TGN'],
+        'MEN' => ['C27','STF','SGN','BRD'],
+        'WHM' => ['J25','STF','BBB','PST'],
+        'HSM' => ['GHR','BCT','D07','TGN'],
+        'ACT' => ['D04','ECM','P41','TGN'],
         'ECT' => ['KSG','HSK','WBM','GLS'],
         'FNR' => ['J10','J12','BST','WMB'],
-        'HOH' => ['M13','WMB','M15','UXB'],
+        'HOH' => ['M21','WMB','M07','UXB'],
         'EBK' => ['CRS','WLO','TMP','WMN'],
         'WLO' => ['EBK','B24','WMN','J19'],
         'TCR' => ['OXC','HBN','N24','LSQ'],
         'LON' => ['J19','J21','N42','BNK'],
         'BNK' => ['C24','LON','MGT','LST'],
         'MGT' => ['LST','BBC','BNK','N46'],
-        'HBN' => ['TCR','C23','P27','P29'],
-        'FBP' => ['V11','V13','P33','P35'],
+        'HBN' => ['TCR','C23','P24','P26'],
+        'FBP' => ['V11','V13','P31','P33'],
         'PCS' => ['OXC','CRS','LSQ','GPK'],
-        'WMB' => ['J4','J6','FNR','M12','HOH'],
+        'WMB' => ['J04','J06','FNR','M22','HOH'],
         'GPK' => ['VCT','OXC','BOS','WMN','LSQ'],
         'WMN' => ['SJP','GPK','WLO','EBK','WLO'],
         'WTC' => ['C11','C13','LTR','WDL','C13'],
-        'LST' => ['MGT','AGT','AGE','BNK','C29'],
-        'TGN' => ['D42','D44','GBY','HSM','ACT'],
-        'OXC' => ['V6','WST','BOS','B18','PCS','TCR'],
-        'KCS' => ['V9','V11','EUS','FRG','N47','P29','P31'],
+        'LST' => ['MGT','AGT','AGE','BNK','C27'],
+        'TGN' => ['D06','D04','GBY','HSM','ACT'],
+        'OXC' => ['GPK','WST','BOS','B18','PCS','TCR'],
+        'KCS' => ['V11','EUS','FRG','N47','P26','P29'],
         'BST' => ['BOS','B18','B16','GPS','J13','EDG','FNR'],
     };
     return $node;
@@ -648,12 +697,13 @@ sub init {
 
 This loads all the nodes defined. Currently covers Bakerloo, Central, Circle,
 District, Hammersmith & City, Jubilee, Metropolitan, Northern, Piccadilly and 
-Victoria. I shall be finishing the last remaining Waterloo & City line very soon. 
+Victoria. I shall be finishing the last remaining Waterloo & City line very soon.
 Please note this is still very experimental in nature.
 
+  use strict; use warnings;
   use Map::Tube::Node;
-  
-  # Loads up the node definitions.
+
+  # Loads all the node definitions.
   my $element = Map::Tube::Node::load_element();
 
 =cut
@@ -671,13 +721,39 @@ sub load_element
             %{$VICTORIA}};
 }
 
+=head2 load_line()
+
+This loads all the tube lines with their node code.
+
+  use strict; use warnings;
+  use Map::Tube::Node;
+
+  # Loads all the node codes with the tube lines information.
+  my $line = Map::Tube::Node::load_line();
+
+=cut
+
+sub load_line
+{
+    my $line = {};
+    foreach (keys %{$LINE})
+    {
+        foreach my $code (@{$LINE->{$_}})
+        {
+            push @{$line->{$code}}, $_;
+        }
+    }
+    return $line;
+}
+
 =head2 upcase_element_name
 
 This loads all the nodes with name in uppercase. This is to allow case-insensitive 
 name lookup. User can also provide the node list otherwise it will pick the default list.
 
+  use strict; use warnings;
   use Map::Tube::Node;
-  
+
   # Returns a new list of element with names in upper case.
   my $upcase = Map::Tube::Node::upcase_element_name();
 
@@ -686,9 +762,9 @@ name lookup. User can also provide the node list otherwise it will pick the defa
 sub upcase_element_name
 {
     my $element = shift;
-    $element = load_element() 
+    $element = load_element()
         unless defined $element;
-    
+
     my $upcase = undef;
     foreach (keys %{$element})
     {
@@ -748,4 +824,4 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
-1; # End of Map::Tube::Node
+1; # End of Map::Tube::Node
\ No newline at end of file
